/**
 *
 * @group providers_interface
 * @namespace ProvidersSystem
 */
function ProvidersSystem() {

    /**
     * Производит сброс всех провайдеров, на которые не ведет ни одна ссылка.
     *
     * Назначение: проверка корректности работы провайдеров и специфичная работа некоторых виджетов.
     *
     * Пример:
     * есть виджеты в которых, осуществляется подписка на паблишер, но она существует только в рамках одного виджета,
     * или одного поиска. Дальше грид не нужен и должен быть удален. (Алармы, Поиски)
     *
     * @example
     * ps.drop_cache()
     *
     * @public
     * @function drop_cache
     * @memberof ProvidersSystem
     */
    this.drop_cache = function () {

    };

    /**
     * Производит разрыв соединения между сервером и клиентом.
     * В зависимости от настроек конфига, будет совершено переподключение.
     *
     * Назначение: проверка заморозки и восстановления состояния провайдеров
     *
     * @example
     * ps.break_connection()
     *
     * @public
     * @function break_connection
     * @memberof ProvidersSystem
     */
    this.break_connection = function () {

    };

    /**
     * Запускает работу провайдеров.
     *
     * @public
     * @function start
     * @memberof ProvidersSystem
     */
    this.start = function () {

    };

    /**
     * Опасный метод.
     *
     * Залогинится как рутовый пользователь. (При условии что name=root and password=root создан на сервере)
     *
     * @public
     * @function sign_as_root
     * @memberof ProvidersSystem
     */
    this.sign_as_root = function () {

    };

    /**
     * Произвести авторизацию в системе по имени пользователя
     *
     * @example
     * ps.auth_by_password("user", "password")
     * // Важно! При успешной авторизации идентификатор сессии записывается в куку.
     * // Доступ к куке осущеставляется таким образом
     * var tools = require("providers/tools/lib")
     * tools.storage.session.get()
     *
     * @public
     * @param {string} _login Имя пользователя
     * @param {string} _password Пароль пользователя
     * @param {function} _callback Вызовется когда придет результат авторизации
     * @function auth_by_password
     * @memberof ProvidersSystem
     */
    this.auth_by_password = function (_login, _password, _callback) {

    };

    /**
     * Произвести авторизацию в системе по идентификатору сессии
     *
     * @example
     * var tools = require("providers/tools/lib")
     * var session = tools.storage.session.get();
     * if(session != null){
     *     ps.auth_by_session_id(session, function(_ev){
     *         console.log(_ev)
     *     });
     * }
     *
     * @public
     * @function auth_by_session_id
     * @param {string} _session_id Идентификатор сессии
     * @param {function} _callback Вызовется когда придет результат авторизации
     * @memberof ProvidersSystem
     */
    this.auth_by_session_id = function (_session_id, _callback) {

    };


    /**
     *
     * @name s_connected
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_connected = -1;

    /**
     *
     * @name s_connecting
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_connecting = -1;

    /**
     *
     * @name s_platform_up
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_platform_up = -1;

    /**
     *
     * @name s_platform_down
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_platform_down = -1;
    
    /**
     *
     *
     * @name s_platform_broken
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_platform_broken = -1;

    /**
     * 
     *
     * @name s_wait_login
     * @public
     * @memberof ProvidersSystem
     * @type {number}
     */
    this.s_wait_login = -1;
}